==> kdelibs-3.1.4.tar.bz2: kdelibs-3.1.4/khtml/rendering/render_body.h <==
/*
 * This file is part of the html renderer for KDE.
 *
 * Copyright (C) 2000 Lars Knoll (knoll@kde.org)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * $Id: render_body.h,v 1.10.4.3 2003/05/18 12:34:40 mueller Exp $
 */
#ifndef RENDER_BODY
#define RENDER_BODY

#include "rendering/render_flow.h"

namespace DOM
{
    class HTMLBodyElementImpl;
}

namespace khtml {

class RenderBody : public RenderFlow
{
public:
    RenderBody(DOM::HTMLBodyElementImpl* node);
    virtual ~RenderBody();

    virtual bool isBody() const { return true; }

    virtual const char *renderName() const { return "RenderBody"; }
    virtual void repaint();

    virtual void layout();
    virtual void setStyle(RenderStyle* style);

    virtual int availableHeight() const;

protected:
    virtual void paintBoxDecorations(QPainter *p,int _x, int _y,
                                     int _w, int _h, int _tx, int _ty);
    bool scrollbarsStyled;
};

} // end namespace
#endif

==> kdelibs-3.2.3.tar.bz2: kdelibs-3.2.3/khtml/rendering/render_body.h <==
/*
 * This file is part of the html renderer for KDE.
 *
 * Copyright (C) 2000-2003 Lars Knoll (knoll@kde.org)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * $Id: render_body.h,v 1.16.2.1 2004/02/29 15:27:59 mueller Exp $
 */
#ifndef RENDER_BODY
#define RENDER_BODY

#include "rendering/render_block.h"

namespace DOM
{
    class HTMLBodyElementImpl;
}

namespace khtml {

class RenderBody : public RenderBlock
{
public:
    RenderBody(DOM::HTMLBodyElementImpl* node);
    virtual ~RenderBody();

    virtual bool isBody() const { return true; }

    virtual const char *renderName() const { return "RenderBody"; }
    virtual void repaint(bool immediate=false);

    virtual void layout();
    virtual void setStyle(RenderStyle* style);

    virtual int availableHeight() const;

protected:
    virtual void paintBoxDecorations(PaintInfo&, int _tx, int _ty);
    bool scrollbarsStyled;
};

} // end namespace
#endif
